<?php
/**
 * @file MyGuestbook.php
 * @package MyGuestbook
 * @update 06.06.2010
 * @author Stefan Benicke
 * @copyright Stefan Benicke <http://www.opusonline.at>
 * @license GNU GPL v3 <http://www.gnu.org/licenses/gpl-3.0.html>
 * @version 1.4
 */
defined('is_running') or die('Not an entry point...');

class MyGuestbook
{
	var $version = '1.4';
	var $config = array();
	var $configFile;

	function MyGuestbook()
	{
		$this->init();

		$cmd = common::GetCommand();

		if (common::LoggedIn()) {
			switch($cmd) {
				case 'edit':
					$this->adminEditEntry();
					break;
				case 'admin_save':
					if ($this->adminSaveEntry()) $this->adminShowEntries();
					else $this->adminEditEntry();
					break;
				case 'delete':
					$this->adminDeleteEntry();
					$this->adminShowEntries();
					break;
				case 'config':
					$this->adminConfig();
					break;
				case 'save_config':
					$this->adminSaveConfig();
					$this->adminConfig();
					break;
				case 'about':
					$this->about();
					break;
				default:
					$this->adminShowEntries();
					break;
			}
		}
		else {
			switch($cmd) {
				case 'sign':
					$this->formSign();
					break;
				case 'save':
					if (!$this->saveNewEntry()) $this->formSign();
					else $this->showEntries();
					break;
				case 'preview':
					echo $this->parseBBCode($_POST['text']);
					die();
				case 'help':
					$this->help();
					break;
				default:
					$this->showEntries();
					break;
			}
		}
	}

	function init()
	{
		global $langmessage, $addonPathData, $page, $addonFolderName, $addonRelativeCode;

		$this->configFile = $addonPathData.'/index.php';
		$this->getData();

		$page->head .= '<link rel="stylesheet" href="'.$addonRelativeCode.'/style.css" />';
		$page->admin_links[$langmessage['admin']] = common::GetUrl('Special_MyGuestbook');
		$page->admin_links[$langmessage['configuration']] = common::GetUrl('Special_MyGuestbook','cmd=config');
		$page->admin_links[] = array('Admin_Theme_Content',$langmessage['editable_text'],'cmd=addontext&addon='.urlencode($addonFolderName),' name="ajax_box" ');
		$page->admin_links[$langmessage['about']] = common::GetUrl('Special_MyGuestbook','cmd=about');
	}

	function getData()
	{
		if (file_exists($this->configFile)) {
			require($this->configFile);
			$this->config = $MyGuestbookConfig;
		}
		else {
			$this->config = array('label'=>'MyGuestbook', 'order'=>'last', 'dateFormat'=>'n/j/Y', 'perPage'=>'5', 'entry'=>array());
			$this->save();
		}
	}

	function showEntries()
	{
		$page = (isset($_GET['page'])) ? $_GET['page'] : 0;
		$number = (isset($this->config['entry'])) ? count($this->config['entry']) : 0;

		echo '<h2>'.$this->config['label'].'</h2>'."\n";
		echo "<p>$number ".gpOutput::GetAddonText('Entries').' - '.common::Link('Special_MyGuestbook', gpOutput::GetAddonText('Sign Guestbook'), 'cmd=sign').'</p>'."\n";

		if ($this->config['perPage'] == 'all') {
			if ($this->config['order'] == 'last') {
				$i = $number-1;
				$to = -1;
			}
			else {
				$i = 0;
				$to = $number;
			}
		}
		else {
			if ($this->config['order'] == 'last') {
				$i = ($number - 1) - ($page * (int)$this->config['perPage']);
				if ($i < 0) $i = 0;
				if ($i >= $number) $i = $number-1;
				$to = $i - (int)$this->config['perPage'];
				if ($to < -1) $to = -1;
			}
			else {
				$i = $page * (int)$this->config['perPage'];
				if ($i < 0) $i = 0;
				$to = $i + (int)$this->config['perPage'];
				if ($to > $number) $to = $number;
			}
		}
		while ($i != $to)
		{
			echo '<h2 class="myguestbook_name">'.$this->config['entry'][$i]['name'].'</h2><div class="myguestbook_info">'.date($this->config['dateFormat'], $this->config['entry'][$i]['date']).'</div><div class="myguestbook_text">'.$this->config['entry'][$i]['text'].'</div>'."\n";
			if ($this->config['order'] == 'last') $i--;
			else $i++;
		}
		if ($this->config['perPage'] != 'all') {
			$prev = 'page='.($page-1);
			if (($page-1) <= 0) $prev = '';
			$next = 'page='.($page+1);
			$pageNumber = ceil($number / (int)$this->config['perPage'])-1;
			if ($this->config['order'] == 'last') {
				$prevText = gpOutput::GetAddonText('Newer Entries');
				$nextText = gpOutput::GetAddonText('Older Entries');
			}
			else {
				$prevText = gpOutput::GetAddonText('Older Entries');
				$nextText = gpOutput::GetAddonText('Newer Entries');
			}
			if ($page > 0) echo common::Link('Special_MyGuestbook', $prevText, $prev);
			echo ' ';
			if ($page < $pageNumber) echo common::Link('Special_MyGuestbook', $nextText, $next);
		}
	}

	function formSign()
	{
		global $langmessage, $config, $rootDir, $addonRelativeCode;
		$name = (isset($_POST['name'])) ? $_POST['name'] : '';
		$text = (isset($_POST['text'])) ? $_POST['text'] : '';
		common::AddColorBox();

		echo '<script type="text/javascript">$(document).ready(function(){$(".bbcode").colorbox({inline:true,href:"#my_guestbook_help"});$(".preview").click(function(){$("#myguestbook_preview").slideUp(300, function(){$.post("'.$_SERVER['PHP_SELF'].'?cmd=preview", {text:$("#myguestbook_text").val()}, function(data){$("#myguestbook_preview").html(data).slideDown(300);});});});});</script>'."\n";
		echo '<div style="display:none"><div id="my_guestbook_help" class="inline_box">'."\n";
		$this->help();
		echo '</div></div>'."\n";

		echo '<h2>'.gpOutput::GetAddonText('Sign Guestbook').'</h2>'."\n";
		echo '<form action="'.common::GetUrl('Special_MyGuestbook','cmd=save').'" class="myguestbook_form" method="post"><table><tr><td><label for="myguestbook_name">'.gpOutput::GetAddonText('Name').'*</label></td><td><input type="text" name="name" id="myguestbook_name" class="text" value="'.$name.'" size="30" /></td></tr><tr><td><label for="myguestbook_text">'.gpOutput::GetAddonText('Text').'*</label></td><td><textarea cols="30" rows="6" name="text" id="myguestbook_text">'.$text.'</textarea><br /><small><a href="'.common::GetUrl('Special_MyGuestbook', 'cmd=help').'" class="bbcode">'.gpOutput::GetAddonText('You can use BBCode').'</a></small></td></tr><tr>'."\n";
		// if reCaptcha	is enabled
		if (!empty($config['recaptcha_public']) and !empty($config['recaptcha_private'])) {
			require_once($rootDir.'/include/thirdparty/recaptchalib.php');
			$lang = $config['recaptcha_language'];
			$recaptchaLangs = array('en', 'nl', 'fr', 'de', 'pt', 'ru', 'es', 'tr');
			if ($lang == 'inherit') {
				$lang = (in_array($config['language'], $recaptchaLangs)) ? $config['language'] : 'en';
			}
			$recaptchaScript = '<script>var RecaptchaOptions = { lang : "'.$lang.'" };</script>';
			echo '<td><label for="captcha">'.gpOutput::GetAddonText('Captcha').'</label></td><td>'.$recaptchaScript.recaptcha_get_html($config['recaptcha_public']).'</td></tr><tr>'."\n";
		}
		echo '<td></td><td><div id="myguestbook_preview" style="display:none"></div><p><input type="submit" class="submit" name="" value="'.$langmessage['save'].'" /> <script type="text/javascript">document.write(\'<input type="button" class="preview submit" value="'.gpOutput::GetAddonText('Preview').'" /> \')</script><input type="reset" class="submit" value="'.$langmessage['cancel'].'" onclick="javascript:location.href=\''.common::GetUrl('Special_MyGuestbook').'\'" /></p></td></tr></table></form>'."\n";
	}

	// from special/special_contact.php
	function CheckCaptcha()
	{
		global $langmessage, $config, $rootDir;
		
		if (empty($config['recaptcha_public']) or empty($config['recaptcha_private'])) {
			return true;
		}
		require_once($rootDir.'/include/thirdparty/recaptchalib.php');
		$resp = recaptcha_check_answer($config['recaptcha_private'], $_SERVER['REMOTE_ADDR'], $_POST['recaptcha_challenge_field'], $_POST['recaptcha_response_field']);
		
		if (!$resp->is_valid) {
			message($langmessage['INCORRECT_CAPTCHA']);
			if (common::LoggedIn()) {
				message($langmessage['recaptcha_said'], $resp->error);
			}
			return false;
		}
		return true;
	}

	function saveNewEntry()
	{
		global $langmessage;

		if (!$this->CheckCaptcha() or !isset($_POST['name']) or !isset($_POST['text']) or empty($_POST['name']) or empty($_POST['text'])) {
			if (!isset($_POST['name']) or empty($_POST['name'])) {
				$field = gpOutput::GetAddonText('Name');
				message($langmessage['OOPS_REQUIRED'], $field);
			}
			if (!isset($_POST['text']) or empty($_POST['text'])) {
				$field = gpOutput::GetAddonText('Text');
				message($langmessage['OOPS_REQUIRED'], $field);
			}
			return false;
		}

		$number = (isset($this->config['entry'])) ? count($this->config['entry']) : 0;
		$this->config['entry'][$number]['date'] = time();
		$this->config['entry'][$number]['name'] = $_POST['name'];
		$this->config['entry'][$number]['text'] = $this->parseBBCode($_POST['text']);
		
		$this->save();

		return true;
	}

	function parseBBCode(&$text)
	{
		global $addonRelativeCode;
		$smileys = $addonRelativeCode.'/images/smileys/';
		$text = strip_tags(htmlspecialchars($text));
		$text = preg_replace("/\015\012|\015|\012/", "\n", $text);
		$text = str_replace(':)', '<img src="'.$smileys.'smile.gif" />', $text);
		$text = str_replace(';)', '<img src="'.$smileys.'wink.gif" />', $text);
		$text = str_replace(':P', '<img src="'.$smileys.'tongue.gif" />', $text);
		$text = str_replace(':D', '<img src="'.$smileys.'biggrin.gif" />', $text);
		$text = str_replace(':o', '<img src="'.$smileys.'redface.gif" />', $text);
		$text = str_replace(':(', '<img src="'.$smileys.'frown.gif" />', $text);
		$text = str_replace(':mad:', '<img src="'.$smileys.'mad.gif" />', $text);
		$text = str_replace(':confused:', '<img src="'.$smileys.'confused.gif" />', $text);
		$text = str_replace(':rolleyes:', '<img src="'.$smileys.'rolleyes.gif" />', $text);
		$text = str_replace(':cool:', '<img src="'.$smileys.'cool.gif" />', $text);
		$text = str_replace(':eek:', '<img src="'.$smileys.'eek.gif" />', $text);
		$text = preg_replace('#\[b\](.*)\[/b\]#isU', "<strong>$1</strong>", $text);
		$text = preg_replace('#\[i\](.*)\[/i\]#isU', "<em>$1</em>", $text);
		$text = preg_replace('#\[u\](.*)\[/u\]#isU', "<u>$1</u>", $text);
		$text = preg_replace('#\[s\](.*)\[/s\]#isU', "<strike>$1</strike>", $text);
		$text = preg_replace('#\[color=(.*)\](.*)\[/color\]#isU', "<span style=\"color:$1\">$2</span>", $text);
		$text = preg_replace('#\[size=(8|10|12)\](.*)\[/size\]#isU', "<span style=\"font-size:$1pt\">$2</span>", $text);
		$text = preg_replace('#\[url\](.*)\[/url\]#isU', "<a href=\"$1\">$1</a>", $text);
		$text = preg_replace('#\[url=(.*)\](.*)\[/url\]#isU', "<a href=\"$1\">$2</a>", $text);
		$text = preg_replace('#\[email\](.*)\[/email\]#isU', "<a href=\"mailto:$1\">$1</a>", $text);
		$text = preg_replace('#\[img\](.*)\[/img\]#isU', "<img src=\"$1\" alt=\"$1\" />", $text);
		$text = preg_replace('#\[quote\](.*)\[/quote\]#isU', "<blockquote><p>$1</p></blockquote>", $text);
		$text = preg_replace('#\[code\](.*)\[/code\]#isU', "<code>$1</code>", $text);
		$text = preg_replace('#\[list\](.*)\[/list\]#isU', "<ul>$1\n</ul>", $text);
		$text = preg_replace('#\[list=(1|a)\](.*)\[/list\]#isU', "<ol type=\"$1\">$2</ol>", $text);
		$text = preg_replace('#\[\*\]#isU', "\n[*]", $text);
		$text = preg_replace('#\[\*\](.*)\n#isU', "<li>$1</li>", $text);
		$text = preg_replace('#\n\n#isU', "</p>\n<p>", $text);
		
		return "<p>$text</p>";
	}

	function adminShowEntries()
	{
		global $langmessage;
		$number = (isset($this->config['entry'])) ? count($this->config['entry']) : 0;

		echo '<div style="display:none"><div id="myguestbook_entry_delete" class="inline_box"><form action="'.common::getUrl('Special_MyGuestbook').'" method="post"><p>'.$langmessage['delete_confirm'].'</p><p style="text-align:right"><input type="hidden" name="id" value="" /><input type="hidden" name="cmd" value="delete" /><input type="submit" name="aaa" value="'.$langmessage['delete'].'" /><input type="button" name="" value="Cancel" onclick="javascript:$(this).colorbox.close()" /></p></form></div></div>'."\n";
		echo '<h2>'.$this->config['label']."</h2><p>$number ".gpOutput::GetAddonText('Entries')."</p>\n";
		
		for ($i = 0; $i < $number; $i++) {
			$input = '<input type="hidden" name="id" value="'.$i.'" />'."\n";
			echo '<h2 class="myguestbook_name">'.$this->config['entry'][$i]['name'].'</h2><div class="myguestbook_info">'.date($this->config['dateFormat'], $this->config['entry'][$i]['date']).' - '.common::Link('Special_MyGuestbook', $langmessage['edit'], 'cmd=edit&id='.$i).' '.common::Link('Special_MyGuestbook', $langmessage['delete'].$input, 'cmd=popup', ' name="inline_box" rel="#myguestbook_entry_delete"').'</div><div class="myguestbook_text">'.$this->config['entry'][$i]['text'].'</div><br />'."\n";
		}
	}

	function adminEditEntry()
	{
		global $langmessage;
		
		echo '<h2>'.$this->config['label'].' '.$langmessage['edit'].'</h2>';
		if (isset($_REQUEST['id'])) {
			$id = (int)$_REQUEST['id'];
			echo '<form action="'.common::getUrl('Special_MyGuestbook').'" method="post"><h4>'.gpOutput::GetAddonText('Name').'</h4><p><input type="text" name="name" size="30" value="'.$this->config['entry'][$id]['name'].'" /></p><h4>'.gpOutput::GetAddonText('Text').'</h4>';
			common::UseFCK($this->config['entry'][$id]['text'], 'text');
			echo '<p><input type="hidden" name="cmd" value="admin_save" /><input type="hidden" name="id" value="'.$id.'" /><input type="hidden" name="date" value="'.$this->config['entry'][$id]['date'].'" /><input type="submit" name="" value="'.$langmessage['save'].'" /><input type="submit" name="cmd" value="'.$langmessage['cancel'].'" /></p></form>'."\n";
		}
		else {
			message($langmessage['OOPS']);
			$this->adminShowEntries();
		}
	}

	function adminSaveEntry()
	{
		global $langmessage;

		if (isset($_POST['name']) and isset($_POST['text']) and isset($_POST['id']) and isset($_POST['date']) and !empty($_POST['name']) and !empty($_POST['text'])) {
			$id = (int)$_POST['id'];
			$this->config['entry'][$id]['name'] = htmlspecialchars($_POST['name']);
			$this->config['entry'][$id]['date'] = (int)$_POST['date'];
			$this->config['entry'][$id]['text'] = $_POST['text'];

			$this->save();
			
			return true;
		}
		else {
			if (empty($_POST['name'])) message($langmessage['OOPS_REQUIRED'], gpOutput::GetAddonText('Name'));
			if (empty($_POST['text'])) message($langmessage['OOPS_REQUIRED'], gpOutput::GetAddonText('Text'));
		}
		return false;
	}

	function adminDeleteEntry()
	{
		global $langmessage;

		if (isset($_POST['id'])) {
			$id = (int)$_POST['id'];
			array_splice($this->config['entry'], $id, 1);
			$this->save();
		}
		else {
			message($langmessage['OOPS']);
		}
	}

	function adminConfig()
	{
		global $langmessage, $addonPathCode, $addonRelativeCode;
		
		echo '<h3>'.$this->config['label'].' '.$langmessage['configuration']."</h3>\n";
		
		echo '<form action="'.common::getUrl('Special_MyGuestbook').'" method="post"><table width="100%" class="bordered"><thead><tr><th>Option</th><th>Value</th><th>Default</th></tr></thead><tbody><tr><td>Label</td><td><input type="text" name="label" size="30" value="'.htmlspecialchars($this->config['label']).'" /></td><td>MyGuestbook</td></tr><tr><td>Entries per Page<br /><small>You can also use \'all\'</small></td><td><input type="text" name="perPage" size="30" value="'.htmlspecialchars($this->config['perPage']).'" /></td><td>5</td></tr><tr><td>Order<br /><small>\'last\' or \'first\'</small></td><td><input type="text" name="order" size="30" value="'.htmlspecialchars($this->config['order']).'" /></td><td>last</td></tr><tr><td>Date Format<br /><small>(<a href="http://php.net/manual/en/function.date.php">About</a>)</small></td><td><input type="text" name="dateFormat" size="30" value="'.htmlspecialchars($this->config['dateFormat']).'" /></td><td>n/j/Y</td></tr><tr><td>&nbsp;</td><td><input type="hidden" name="cmd" value="save_config" /><input type="submit" name="" value="'.$langmessage['save'].'" /><input type="submit" name="cmd" value="'.$langmessage['cancel'].'" /></td><td>&nbsp;</td></tbody></table></form>'."\n";
		echo '<h4>Captcha</h4><p>If you want to protect your Guestbook with a Captcha you can use the service of <a href="http://recaptcha.net/whyrecaptcha.html">reCaptcha</a>. Registration is free.<br />There you get one pair of keys wich you insert and save in the '.common::Link('Admin_Configuration', 'Admin Configuration').'. That\'s it!<br />Automatically your Guestbook and even your contact form will be protected.</p>'."\n";
		echo '<h4>Style</h4><p>There\'s a little stylesheet for the BBCode help site. You can open it from "<a href="'.$addonRelativeCode.'/style.css">'.$addonPathCode.'/style.css</a>" and edit it with every Texteditor.</p><p>For styling you have \'h2.myguestbook_name\', \'div.myguestbook_info\', \'div.myguestbook_text\', \'form.myguestbook_form\', \'input#myguestbook_name\' and \'textarea#myguestbook_text\'. But I hope this will be implemented in every template in the future.</p>'."\n";
	}

	function adminSaveConfig()
	{
		global $langmessage, $rootDir;
		$pages_file = $rootDir.'/data/_site/pages.php';
		include $pages_file;
		
		$this->config['label'] = (isset($_POST['label']) and !empty($_POST['label'])) ? htmlspecialchars($_POST['label']) : 'MyGuestbook';
		$this->config['dateFormat'] = $_POST['dateFormat'];
		$this->config['order'] = $_POST['order'];
		$this->config['perPage'] = ((int)$_POST['perPage'] > 0 or $_POST['perPage'] == 'all') ? $_POST['perPage'] : '1';
		
		if ($this->config['label'] == $pages['gptitles']['Special_MyGuestbook']['label']) {
			$this->save();
		}
		else {
			if ($this->saveConfig() and $this->savePages($this->config['label'])) {
				message($langmessage['SAVED']);
				message('To see the changes taking effect please '.common::Link('Special_MyGuestbook', 'reload', 'cmd=config').'.');
			}
			else {
				message($langmessage['OOPS']);
			}
		}
	}

	function save()
	{
		global $langmessage;

 		if ($this->saveConfig()) {
			message($langmessage['SAVED']);
		}
		else {
			message($langmessage['OOPS']);
		}
	}

	function saveConfig()
	{
		return gpFiles::SaveArray($this->configFile, 'MyGuestbookConfig', $this->config);
	}

	function savePages(&$label)
	{
		global $rootDir;
		$pages_file = $rootDir.'/data/_site/pages.php';
		include $pages_file;
		
		$pages['gptitles']['Special_MyGuestbook']['label'] = $label;

		if (gpFiles::SaveArray($pages_file, 'pages', $pages)) {
			return true;
		}
		return false;
	}

	function help()
	{
		global $addonRelativeCode;

		echo '<table class="bordered"><thead><tr><th>BBCode</th><th>Effect</th></tr></thead><tbody><tr><td><code>[b]bolded text[/b]</code></td><td><b>bolded text</b></td></tr><tr><td><code>[i]italicized text[/i]</code></td><td><i>italicized text</i></td></tr><tr><td><code>[u]underlined text[/u]</code></td><td><span style="text-decoration:underline;">underlined text</span></td></tr><tr><td><code>[s]strikethrough text[/s]</code></td><td><s>strikethrough text</s></td></tr><tr><td><code>[url]http://example.org[/url]</code></td><td><a href="http://example.org" rel="nofollow">http://example.org</a></td></tr><tr><td><code>[url=http://example.com]Example[/url]</code></td><td><a href="http://example.com" rel="nofollow">Example</a></td></tr><tr><td><code>[email]mail@mail.com[/email]</code></td><td><a href="mailto:mail@mail.com">mail@mail.com</a></td></tr><tr><td><code>[img]http://example.com/book.png[/img]</code></td><td><img src="'.$addonRelativeCode.'/images/book.png" width="54" height="50" alt="book.png" /></td></tr><tr><td><code>[quote]quoted text[/quote]</code></td><td><blockquote><p>quoted text</p></blockquote></td></tr><tr><td><code>[code]monospaced text[/code]</code></td><td><code>monospaced text</code></td></tr><tr><td><code>[size=8]Small Text[/size]</code><br /><small>(8, 10, 12)</small></td><td><span style="font-size:8pt">Small Text</span></td></tr><tr><td><code>[color=red]Red Text[/color]</code><br /><small>or</small><br /><code>[color=#FF0000]Red Text[/color]</code></td><td><span style="color:#f00">Red Text</span></td></tr><tr><td><code>[list]<br />[*]First Item<br />[*]Second Item<br />[/list]</code><br /><small>(Also allowed <code>[list=1]</code> or <code>[list=a]</code>)</small></td><td><ul class="help"><li>First Item</li><li>Second Item</li></ul></td></tr></tbody></table>'."\n";
		$smileys = $addonRelativeCode.'/images/smileys/';
		echo '<table class="bordered"><thead><tr><th>Smiley</th><th>Image</th></tr></thead><tbody><tr><td>:)</td><td><img src="'.$smileys.'smile.gif" /></td></tr><tr><td>;)</td><td><img src="'.$smileys.'wink.gif" /></td></tr><tr><td>:P</td><td><img src="'.$smileys.'tongue.gif" /></td></tr><tr><td>:D</td><td><img src="'.$smileys.'biggrin.gif" /></td></tr><tr><td>:o</td><td><img src="'.$smileys.'redface.gif" /></td></tr><tr><td>:(</td><td><img src="'.$smileys.'frown.gif" /></td></tr><tr><td>:mad:</td><td><img src="'.$smileys.'mad.gif" /></td></tr><tr><td>:confused:</td><td><img src="'.$smileys.'confused.gif" /></td></tr><tr><td>:rolleyes:</td><td><img src="'.$smileys.'rolleyes.gif" /></td></tr><tr><td>:cool:</td><td><img src="'.$smileys.'cool.gif" /></td></tr><tr><td>:eek:</td><td><img src="'.$smileys.'eek.gif" /></td></tr></tbody></table>';
		//echo '<p>'.common::Link('Special_MyGuestbook', gpOutput::GetAddonText('Back'), 'cmd=sign').'</p>';
	}

	function about()
	{
		global $langmessage;

		echo '<h3>MyGuestbook '.$langmessage['about'].'</h3>'."\n";
		echo '<p>Version '.$this->version.'</p><p>Licensed under version 3 of the <a href="http://www.gnu.org/licenses/gpl-3.0.html">GNU General Public License</a></p><p>Copyright 2010 Stefan Benicke (<a href="http://www.opusonline.at/">opusonline.at</a>)</p>'."\n";
	}
}
