<?php
defined('is_running') or die('Not an entry point...');


class SimpleBlogCommon{
	
	var $indexFile;
	var $blogData = array();
	
	function Init(){
		global $page,$addonRelativeCode,$addonPathData;
		
		
		$page->head .= '<link rel="stylesheet" type="text/css" href="'.$addonRelativeCode.'/style.css'.'" />';
		$this->indexFile = $addonPathData.'/index.php';
		$this->blogData = SimpleBlogCommon::GetBlogData();
	}

	
	
	function GetBlogData(){
		global $addonPathData,$config;
		$file = $addonPathData.'/index.php';
				
		$blogData = array();
		if( file_exists($file) ){
			require($file);
		}
		
		//old twitter auth no longer works
		if( isset($blogData['twitter_username']) || isset($blogData['twitter_password']) ){
			unset($blogData['twitter_username']);
			unset($blogData['twitter_password']);
		}
		
		return $blogData + SimpleBlogCommon::Defaults();
	}
	
	function Defaults(){
		global $config;
		return array(	'post_list'=>array(),
						'post_index'=>0,
						'per_page'=>10,
						'gadget_entries'=>3,
						'gadget_abbrev'=>90,
						'feed_entries'=>10,
						'feed_abbrev'=>1200,
						'feed_author'=>$config['title'],
						'date_format'=>'n/j/Y',
						'bitly_login'=>'',
						'bitly_key'=>'',
						'post_info'=>'',
						'allow_comments'=>false,
						'commenter_website'=>'',
						'comment_captcha'=>true
						);
		
	}
	
	function GetPostFile($post_index,&$post_file){
		global $addonPathData;
		
		if( !is_numeric($post_index) ){
			return false;
		}
		
		$file_index = floor($post_index/20);
		$post_file = $addonPathData.'/posts_'.$file_index.'.php';
		if( !file_exists($post_file) ){
			return false;
		}
		
		require($post_file);
		return $posts;
	}
	
	function SaveIndex(){
		return gpFiles::SaveArray($this->indexFile,'blogData',$this->blogData);
	}
	
	function Delete(){
		global $langmessage;
		
		$post_index = $_POST['id'];
		$posts = $this->GetPostFile($post_index,$post_file);
		if( $posts === false ){
			message($langmessage['OOPS']);
			return false;
		}
		
		if( !isset($posts[$post_index]) ){
			message($langmessage['OOPS']);
			return false;
		}
			
		unset($posts[$post_index]); //don't use array_splice because it will reset the numeric keys
		
		$key = array_search((int)$post_index,$this->blogData['post_list'],true);
		if( !is_integer($key) ){
			message($langmessage['OOPS']);
			return false;
		}
		
		array_splice($this->blogData['post_list'], $key, 1); //we want to reset the numeric keys here.

		
		if( !$this->SaveIndex() ){
			message($langmessage['OOPS']);
			return false;
		}
		
		//save to data file
		if( !gpFiles::SaveArray($post_file,'posts',$posts) ){
			message($langmessage['OOPS']);
			return false;
		}
		
		message($langmessage['file_deleted']);
		return true;
	}

	
	function SaveNew(){
		global $langmessage, $addonPathData;
		
		$_POST += array('title'=>'','content'=>'');

		$title = gpFiles::CleanTitle($_POST['title']);
		if( empty($title) ){
			message($langmessage['TITLE_REQUIRED']);
			return false;
		}
		
		$content =& $_POST['content'];
		admin_tools::tidyFix($content);
		
		
		//use current data file or create new one
		$post_index = $this->blogData['post_index'] +1;
		$posts = $this->GetPostFile($post_index,$post_file);

		
		$posts[$post_index] = array();
		$posts[$post_index]['title'] = $title;
		$posts[$post_index]['content'] = $content;
		$posts[$post_index]['time'] = time();
		
		//save to data file
		if( !gpFiles::SaveArray($post_file,'posts',$posts) ){
			message($langmessage['OOPS']);
			return false;
		}
		
		//save index file
		array_unshift($this->blogData['post_list'],$post_index);
		//$this->blogData['post_list'][] = $post_index;
		$this->blogData['post_index'] = $post_index;
		if( !$this->SaveIndex() ){
			message($langmessage['OOPS']);
			return false;
		}
		
		message($langmessage['SAVED']);
		
		$this->UpdateThirdParty($post_index,$title,$content);
		
		return true;
	}
	
	function UpdateThirdParty($post_index,$title,$message){
		
		if( isset($_SERVER['HTTP_HOST']) ){
			$server = 'http://'.$_SERVER['HTTP_HOST'];
		}else{
			$server = 'http://'.$_SERVER['SERVER_NAME'];
		}
		$link = $server.common::GetUrl('Special_Blog','cmd=post&id='.$post_index,false);
		
/*
		if( !empty($this->blogData['twitter_username']) 
			&& !empty($this->blogData['twitter_password'])
			&& !empty($this->blogData['bitly_login'])
			&& !empty($this->blogData['bitly_key'])
			){
				$this->TwitterStatus($link,$title,$message);
			}
*/
		
	}
	
	function TwitterStatus($link,$title,$message){
		
		$shortUrl = $this->GetShortUrl($link);
		if( !$shortUrl ){
			$shortUrl = '';
		}
		
		// username and password
		$username = $this->blogData['twitter_username'];
		$password = $this->blogData['twitter_password'];
	
		// Get the right length for the message
		$message = str_replace('_',' ',$title).': '.strip_tags($message);
		$urlLength = strlen($shortUrl);
		$maxLength = 139 - $urlLength;
		if( strlen($message) > $maxLength ){
			$message = substr($message,0,($maxLength-3));
			$message .= '...';
		}
		$message .= ' '.$shortUrl;
		
		
		// Alternative JSON version
		// $url = 'http://twitter.com/statuses/update.json';
		// Set up and execute the curl process
		$curl_handle = curl_init();
		curl_setopt($curl_handle, CURLOPT_URL, 'http://twitter.com/statuses/update.xml');
		curl_setopt($curl_handle, CURLOPT_CONNECTTIMEOUT, 2);
		curl_setopt($curl_handle, CURLOPT_RETURNTRANSFER, 1);
		curl_setopt($curl_handle, CURLOPT_POST, 1);
		curl_setopt($curl_handle, CURLOPT_POSTFIELDS, 'status='.$message);
		curl_setopt($curl_handle, CURLOPT_USERPWD, $username.':'.$password);
		$buffer = curl_exec($curl_handle);
		curl_close($curl_handle);
		
		// check for success or failure
		if(empty($buffer)) {
			//echo 'message';
			message('Oops, Your Twitter status was not updated.');
		} else {
			//echo 'success';
			// /statuses/update.xml  Status is over 140 characters. 
			//message(showArray($buffer));
			message('Twitter status updated.');
			
		}
	}
	
	function GetShortUrl($link){
		
		//get the short url
		//http://api.bit.ly/shorten?version=2.0.1&longUrl=http://cnn.com&login=bitlyapidemo&apiKey=R_0da49e0a9118ff35f52f629d2d71bf07
		$bitly = 'http://api.bit.ly/shorten?version=2.0.1';
		$bitly .= '&login='.urlencode($this->blogData['bitly_login']);
		$bitly .= '&apiKey='.urlencode($this->blogData['bitly_key']);
		$bitly .= '&longUrl='.urlencode($link);
		$response = file_get_contents($bitly);
		$pos = strpos($response,'"shortUrl"');
		if( !$pos ){
			return false;
		}
		
		$response = substr($response,$pos+10);
		
		$pos = strpos($response,'"');
		if( !$pos ){
			return false;
		}
		$pos++;
		$pos2 = strpos($response,'"',$pos);
		$short = substr($response,$pos,$pos2-$pos);
		return $short;
	}
	
	function SaveEdit(){
		global $langmessage, $addonPathData;
		
		$_POST += array('title'=>'','content'=>'');
		
		$post_index = $_REQUEST['id'];
		$posts = $this->GetPostFile($post_index,$post_file);
		if( $posts === false ){
			message($langmessage['OOPS']);
			return;
		}

		$title = gpFiles::CleanTitle($_POST['title']);
		if( empty($title) ){
			message($langmessage['TITLE_REQUIRED']);
			return false;
		}
		
		$content =& $_POST['content'];
		admin_tools::tidyFix($content);
		gpFiles::rmPHP($content);

		
		$posts[$post_index]['title'] = $title;
		$posts[$post_index]['content'] = $content;
		
		//save to data file
		if( !gpFiles::SaveArray($post_file,'posts',$posts) ){
			message($langmessage['OOPS']);
			return false;
		}
		
		message($langmessage['SAVED']);
		return true;
	}
	
	
	function EditPost(){
		global $langmessage;
		
		if( isset($_POST['id']) ){
			
			$post_index = $_POST['id'];
			$post = $_POST;
			
		}else{
		
			$post_index = $_REQUEST['id'];
			$posts = $this->GetPostFile($post_index,$post_file);
			if( $posts === false ){
				message($langmessage['OOPS']);
				return;
			}
			
			if( !isset($posts[$post_index]) ){
				message($langmessage['OOPS']);
				return;
			}
			$post = $posts[$post_index];
		}

		
		
		echo '<h2>Edit Post</h2>';
		$this->PostForm($post,'save_edit',$post_index);
		return true;
	}
	
	function NewForm(){
		global $langmessage;
		
		echo '<h2>New Blog Post</h2>';
		
		$this->PostForm($_POST);
	}
	
	
	function PostForm(&$array,$cmd='save_new',$post_id=false){
		global $langmessage;
		
		$array += array('title'=>'','content'=>'');
		
		
		echo '<form action="'.common::GetUrl('Special_Blog').'" method="post">';
		echo '<table style="width:100%">';
		
		echo '<tr>';
			echo '<td>';
			echo 'Title';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="title" size="30" value="'.htmlspecialchars($array['title']).'" />';
			echo '</td>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td colspan="2">';
			common::UseFCK( $array['content'],'content' );
			echo '</td>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td colspan="2">';
			echo '<input type="hidden" name="cmd" value="'.$cmd.'" />';
			echo '<input type="hidden" name="id" value="'.$post_id.'" />';
			echo '<input type="submit" name="" value="'.$langmessage['save'].'" />';
			echo '<input type="submit" name="cmd" value="'.$langmessage['cancel'].'" />';
			echo '</td>';
			echo '</tr>';
		
		echo '</table>';
		echo '</form>';
	}
	
	function GenFeed($blog_config){
		global $config, $addonPathData,$addonFolderName,$dirPrefix;
		ob_start();
		
		$atomFormat = 'Y-m-d\TH:i:s\Z';
		if( version_compare('phpversion','5.1.3','>=') ){
			$atomFormat = 'Y-m-d\TH:i:sP';
		}
		
		$posts = array();
		$show_posts = array_slice($blog_config['post_list'], 0, $blog_config['feed_entries'] );

		if( isset($_SERVER['HTTP_HOST']) ){
			$server = 'http://'.$_SERVER['HTTP_HOST'];
		}else{
			$server = 'http://'.$_SERVER['SERVER_NAME'];
		}
		$serverWithDir = $server.$dirPrefix;
		
		
		echo '<?xml version="1.0" encoding="utf-8"?>'."\n";
		echo '<feed xmlns="http://www.w3.org/2005/Atom">'."\n";
		echo '<title>'.$config['title'].'</title>'."\n";
		echo '<link href="'.$serverWithDir.'/data/_addondata/'.str_replace(' ','%20',$addonFolderName).'/feed.atom" rel="self" />'."\n";
		echo '<link href="'.$server.common::GetUrl('Special_Blog').'" />'."\n";
		echo '<id>urn:uuid:'.SimpleBlogCommon::uuid().'</id>'."\n";
		echo '<updated>'.date($atomFormat, time()).'</updated>'."\n";
		echo '<author><name>'.$config['title'].'</name></author>'."\n";


		foreach($show_posts as $post_index){
			
			//get $posts
			if( !isset($posts[$post_index]) ){
				$posts = SimpleBlogCommon::GetPostFile($post_index,$post_file);
			}
			
			if( !isset($posts[$post_index]) ){
				continue;
			}
				
			$post =& $posts[$post_index];
			
			echo '<entry>'."\n";
			echo '<title>'.str_replace('_',' ',$post['title']).'</title>'."\n";
			echo '<link href="'.$server.common::GetUrl('Special_Blog','cmd=post&id='.$post_index).'"></link>'."\n";
			echo '<id>urn:uuid:'.SimpleBlogCommon::uuid().'</id>'."\n";
			echo '<updated>'.date($atomFormat, $post['time']).'</updated>'."\n";
			
			$content =& $post['content'];
			if( ($blog_config['feed_abbrev']> 0) && (strlen($content) > $blog_config['feed_abbrev']) ){
				$content = substr($content,0,$blog_config['feed_abbrev']).' ... ';
				$label = gpOutput::SelectText('Read More');
				$content .= '<a href="'.$server.common::GetUrl('Special_Blog',$label,'cmd=post&id='.$post_index).'">'.$label.'</a>';
			}
			
			//old images
			$replacement = $server.'/';
			$content = str_replace('src="/','src="'.$replacement,$content);
			
			//new images
			$content = str_replace('src="../','src="'.$serverWithDir,$content);
			
			//images without /index.php/
			$content = str_replace('src="./','src="'.$serverWithDir,$content);
			
			
			//href
			SimpleBlogCommon::FixLinks($content,$server,0);
			
			echo '<summary type="html"><![CDATA['.$content.']]></summary>'."\n";
			echo '</entry>'."\n";

		}
		echo '</feed>'."\n";
		
		$feed = common::get_clean();
		$feedFile = $addonPathData.'/feed.atom';
		gpFiles::Save($feedFile,$feed);
	}
	
	
	//recursively turn relative links into absolute links
	function FixLinks(&$content,$server,$offset){
		
		$pos = strpos($content,'href="',$offset);
		if( $pos <= 0 ){
			return;
		}
		$pos = $pos+6;
		$pos2 = strpos($content,'"',$pos);
		
		if( $pos2 <= 0 ){
			return;
		}
		
		//well formed link
		$check = strpos($content,'>',$pos);
		if( ($check !== false) && ($check < $pos2) ){
			SimpleBlogCommon::FixLinks($content,$server,$pos2);
			return;
		}
		
		$title = substr($content,$pos,$pos2-$pos);
		
		//internal link
		if( strpos($title,'mailto:') !== false ){
			SimpleBlogCommon::FixLinks($content,$server,$pos2);
			return;
		}
		if( strpos($title,'://') !== false ){
			SimpleBlogCommon::FixLinks($content,$server,$pos2);
			return;
		}
		
		if( strpos($title,'/') === 0 ){
			$replacement = $server.$title;
		}else{
			$replacement = $server.common::GetUrl($title);
		}
		
		$content = substr_replace($content,$replacement,$pos,$pos2-$pos);
		
		
		SimpleBlogCommon::FixLinks($content,$server,$pos2);
	}
	
	function uuid(){
		$chars = md5(uniqid(rand()));
		$uuid  = substr($chars,0,8).'-'.
		substr($chars,8,4).'-'.
		substr($chars,12,4).'-'.
		substr($chars,16,4).'-'.
		substr($chars,20,12);
		return $uuid;
	}
	
	function GenStaticContent($blog_config = false){
		if( $blog_config === false ){
			$blog_config = SimpleBlogCommon::GetBlogData();
		}
		SimpleBlogCommon::GenFeed($blog_config);
		SimpleBlogCommon::GenGadget($blog_config);
		
		
	}
	
	function GenGadget($blog_config){
		global $langmessage, $addonPathData;
		
		$posts = array();
		$show_posts = array_slice($blog_config['post_list'], 0, $blog_config['gadget_entries'] );

		
		ob_start();
		$label = gpOutput::SelectText('Blog');
		if( !empty($label) ){
			echo '<h3>';
			echo common::Link('Special_Blog',$label);
			echo '</h3>';
		}
		
		foreach($show_posts as $post_index){
			
			//get $posts
			if( !isset($posts[$post_index]) ){
				$posts = SimpleBlogCommon::GetPostFile($post_index,$post_file);
			}
			
			if( !isset($posts[$post_index]) ){
				continue;
			}
				
			$post =& $posts[$post_index];
			
			echo '<b class="simple_blog_title">';
			$label = str_replace('_',' ',$post['title']);
			echo common::Link('Special_Blog',$label,'cmd=post&id='.$post_index);
			echo '</b>';
			echo '<div class="simple_blog_info">';
			echo date($blog_config['date_format'],$post['time']);
			echo '</div>';
			
			$content = strip_tags($post['content']);
			
			if( strlen($content) > $blog_config['gadget_abbrev'] ){
				
				$cut = $blog_config['gadget_abbrev'];
				$pos = strpos($content,' ',$cut-5);
				if( ($pos > 0) && ($cut+20 > $pos) ){
					$cut = $pos;
				}
				$content = substr($content,0,$cut).' ... ';
				
				$label = gpOutput::SelectText('Read More');
				$content .= common::Link('Special_Blog',$label,'cmd=post&id='.$post_index);
			}
			
			echo '<p class="simple_blog_abbrev">';
			echo $content;
			echo '</p>';

		}
		
		if( count($blog_config['post_list']) > 3 ){
			
			$label = gpOutput::SelectText('More Blog Entries');
			echo common::Link('Special_Blog',$label);
		}
		
		$gadget = common::get_clean();
		$gadgetFile = $addonPathData.'/gadget.php';
		gpFiles::Save($gadgetFile,$gadget);
		
		
	}
	
	function SaveConfig(){
		global $langmessage;
		
		
		if( is_numeric($_POST['per_page']) ){
			$this->blogData['per_page'] = (int)$_POST['per_page'];
		}
		
		if( is_numeric($_POST['gadget_entries']) ){
			$this->blogData['gadget_entries'] = (int)$_POST['gadget_entries'];
		}
		
		if( is_numeric($_POST['gadget_abbrev']) ){
			$this->blogData['gadget_abbrev'] = (int)$_POST['gadget_abbrev'];
		}
		
		$format = htmlspecialchars($_POST['date_format']);
		if( @date($format) ){
			$this->blogData['date_format'] = $format;
		}
		
		
		if( is_numeric($_POST['feed_entries']) ){
			$this->blogData['feed_entries'] = (int)$_POST['feed_entries'];
		}
		
		if( is_numeric($_POST['feed_abbrev']) ){
			$this->blogData['feed_abbrev'] = (int)$_POST['feed_abbrev'];
		}
		
		//comments
		if( isset($_POST['allow_comments']) ){
			$this->blogData['allow_comments'] = true;
		}else{
			$this->blogData['allow_comments'] = false;
		}
		$this->blogData['commenter_website'] = (string)$_POST['commenter_website'];
		
		if( isset($_POST['comment_captcha']) ){
			$this->blogData['comment_captcha'] = true;
		}else{
			$this->blogData['comment_captcha'] = true;
		}
		
		
		//twitter/bitly
/*
		$this->blogData['twitter_username'] = (string)$_POST['twitter_username'];
		$this->blogData['twitter_password'] = (string)$_POST['twitter_password'];
		$this->blogData['bitly_login'] = (string)$_POST['bitly_login'];
		$this->blogData['bitly_key'] = (string)$_POST['bitly_key'];
*/
		
		
		
		if( !$this->SaveIndex() ){
			message($langmessage['OOPS']);
			return false;
		}

		
		message($langmessage['SAVED']);
		return true;
	}
	
	
	function Config(){
		global $langmessage,$addonFolderName;
		
		
		$defaults = SimpleBlogCommon::Defaults();
		$array =& $this->blogData;
		
		echo '<h2>Configuration</h2>';
		
		echo '<form class="renameform" action="'.common::GetUrl('Special_Blog').'" method="post">';
		echo '<table style="width:100%" class="bordered">';
		echo '<tr>';
			echo '<th>';
			echo 'Option';
			echo '</th>';
			echo '<th>';
			echo 'Value';
			echo '</th>';
			echo '<th>';
			echo 'Default';
			echo '</th>';
			echo '</tr>';
		
		echo '<tr>';
			echo '<td>';
			echo 'Entries Per Page';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="per_page" size="30" value="'.htmlspecialchars($array['per_page']).'" />';
			echo '</td>';
			echo '<td>';
			echo $defaults['per_page'];
			echo '</td>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td>';
			echo 'Entries For Gadget';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="gadget_entries" size="30" value="'.htmlspecialchars($array['gadget_entries']).'" />';
			echo '</td>';
			echo '<td>';
			echo $defaults['gadget_entries'];
			echo '</td>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td>';
			echo 'Gadget Abbreviation Length';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="gadget_abbrev" size="30" value="'.htmlspecialchars($array['gadget_abbrev']).'" />';
			echo '</td>';
			echo '<td>';
			echo $defaults['gadget_abbrev'];
			echo '</td>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td>';
			echo 'Date Format';
			echo ' (<a href="http://php.net/manual/en/function.date.php" target="_blank">About</a>)';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="date_format" size="30" value="'.htmlspecialchars($array['date_format']).'" />';
			echo '</td>';
			echo '<td>';
			echo $defaults['date_format'];
			echo '</td>';
			echo '</tr>';

			
		echo '<tr>';
			echo '<td>';
			echo 'Entries For Feed';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="feed_entries" size="30" value="'.htmlspecialchars($array['feed_entries']).'" />';
			echo '</td>';
			echo '<td>';
			echo $defaults['feed_entries'];
			echo '</td>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td>';
			echo 'Feed Abbreviation Length';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="feed_abbrev" size="30" value="'.htmlspecialchars($array['feed_abbrev']).'" />';
			echo '</td>';
			echo '<td>';
			echo $defaults['feed_abbrev'];
			echo '</td>';
			echo '</tr>';
			

		echo '<tr>';
			echo '<th>';
			echo 'Comments';
			echo '</th>';
			echo '<th>';
			echo 'Value';
			echo '</th>';
			echo '<th>';
			echo 'Default';
			echo '</th>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td>';
			echo 'Allow Comments';
			echo '</td>';
			echo '<td>';
			if( $array['allow_comments'] ){
				echo '<input type="checkbox" name="allow_comments" value="allow" checked="checked" />';
			}else{
				echo '<input type="checkbox" name="allow_comments" value="allow" />';
			}
			echo '</td>';
			echo '<td>';
			echo '';
			echo '</td>';
			echo '</tr>';

		echo '<tr>';
			echo '<td>';
			echo 'Commenter Website';
			echo '</td>';
			echo '<td>';
			echo '<select name="commenter_website">';
				if( $array['commenter_website'] == 'nofollow' ){
					echo '<option value="">Hide</option>';
					echo '<option value="nofollow" selected="selected">Nofollow Link</option>';
					echo '<option value="link">Follow Link</option>';
				}elseif( $array['commenter_website'] == 'link' ){
					echo '<option value="">Hide</option>';
					echo '<option value="nofollow" selected="selected">Nofollow Link</option>';
					echo '<option value="link" selected="selected">Follow Link</option>';
				}else{
					echo '<option value="">Hide</option>';
					echo '<option value="nofollow">Nofollow Link</option>';
					echo '<option value="link">Follow Link</option>';
				}
			echo '</select>';
			echo '</td>';
			echo '<td>';
			echo 'Hide';
			echo '</td>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td>';
			echo 'reCaptcha';
			echo '</td>';
			echo '<td>';
			
			if( !gp_recaptcha::isActive() ){
				$disabled = ' disabled="disabled" ';
			}else{
				$disabled = '';
			}
			
			if( $array['comment_captcha'] ){
				echo '<input type="checkbox" name="comment_captcha" value="allow" checked="checked" '.$disabled.'/>';
			}else{
				echo '<input type="checkbox" name="comment_captcha" value="allow" '.$disabled.'/>';
			}
			echo '</td>';
			echo '<td>';
			echo '';
			echo '</td>';
			echo '</tr>';


			
/*
		echo '<tr>';
			echo '<th>';
			echo 'Twitter Options';
			echo '</th>';
			echo '<th>';
			echo 'Value';
			echo '</th>';
			echo '<th>';
			echo 'Default';
			echo '</th>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td colspan="3">';
			echo 'Automatically update your twitter status. To enable, provide your twitter username and password. ';
			echo '<a href="http://bit.ly/account/your_api_key" target="_blank">Bit.ly</a> information is required to obtain shortened urls.';
			echo '</td>';
			
		echo '<tr>';
			echo '<td>';
			echo 'Twitter Username';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="twitter_username" size="30" value="'.htmlspecialchars($array['twitter_username']).'" />';
			echo '</td>';
			echo '<td>';
			echo '&nbsp;';
			echo '</td>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td>';
			echo 'Twitter Password';
			echo '</td>';
			echo '<td>';
			echo '<input type="password" name="twitter_password" size="30" value="'.htmlspecialchars($array['twitter_password']).'" />';
			echo '</td>';
			echo '<td>';
			echo '&nbsp;';
			echo '</td>';
			echo '</tr>';
			
		echo '<tr>';
			echo '<td>';
			echo 'bit.ly Login';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="bitly_login" size="30" value="'.htmlspecialchars($array['bitly_login']).'" />';
			echo '</td>';
			echo '<td>';
			echo '&nbsp;';
			echo '</td>';
			echo '</tr>';
						
		echo '<tr>';
			echo '<td>';
			echo 'bit.ly API Key';
			echo '</td>';
			echo '<td>';
			echo '<input type="text" name="bitly_key" size="30" value="'.htmlspecialchars($array['bitly_key']).'" />';
			echo '</td>';
			echo '<td>';
			echo '&nbsp;';
			echo '</td>';
			echo '</tr>';
*/
			
		echo '<tr>';
			echo '<td>';
			echo '</td>';
			echo '<td>';
			echo '<input type="hidden" name="cmd" value="save_config" />';
			echo '<input type="submit" name="" value="'.$langmessage['save'].'" /> ';
			echo '<input type="submit" name="cmd" value="'.$langmessage['cancel'].'" /> ';
			echo '</td>';
			echo '<td>';
			echo '</td>';
			echo '</tr>';
		
		
		echo '</table>';

		
		
		
		echo '</form>';
		
		
		echo common::Link('Admin_Theme_Content',$langmessage['editable_text'],'cmd=addontext&addon='.urlencode($addonFolderName),' title="'.urlencode($langmessage['editable_text']).'" name="ajax_box" ');
		//echo ' - ';
		//echo common::Link('Special_Blog','Regenerate Gadget','cmd=regen',' name="creq"');
	}
}
